# Exceptions

This section contains the `distilabel` custom exceptions. Unlike [errors](errors.md), exceptions in `distilabel` are used to handle specific situations that can be anticipated and that can be handled in a controlled way internally by the library.

:::distilabel.exceptions.DistilabelException
:::distilabel.exceptions.DistilabelGenerationException
:::distilabel.exceptions.DistilabelOfflineBatchGenerationNotFinishedException
